"""
Klasa BankAccount, reprezentujaca konto bankowe (nie kredytowe - saldo musi byc nieujemne)
Dbamy o zalozenie nieujemnosci we wszystkich metodach, oraz rzucamy wyjatek przy
podejrzanych operacjach (np. wybierania ujemnej kwoty z konta)
"""


class BankAccount:
    def __init__(self, number, balance=0):
        if balance < 0:
            raise ValueError("Cannot create an account with negative balance.")
        self.number = number
        self.balance = balance

    def deposit(self, amount):
        if amount < 0:
            raise ValueError(f"Account number {self.number}: cannot deposit a negative amount.")
        self.balance += amount

    def withdraw(self, amount):
        if amount < 0:
            raise ValueError(f"Account number {self.number}: cannot withdraw a negative amount.")
        if amount > self.balance:
            raise ValueError(f"Account number {self.number}: cannot withdraw {amount} (current balance: {self.balance})")
        self.balance -= amount

    def merge_to(self, other_account):
        if self is other_account:
            raise ValueError(f"Account number {self.number}: cannot merge with itself")
        n = self.balance
        self.withdraw(n)
        other_account.deposit(n)

    def __str__(self):
        return "Account number {}, balance: {}".format(self.number, self.balance)


if __name__ == "__main__":
    account = BankAccount("ACCOUNT-1", 10000)
    print(account) # 1
    account.deposit(500)
    print(account) # 2
    account.withdraw(8000)
    print(account) # 3

    another_account = BankAccount("ACCOUNT-2")
    print(another_account) # 4

    account.merge_to(another_account)
    print(account) # 5
    print(another_account) # 6
    # another_account.withdraw(3000)


